@@ -3,7 +3,7 @@ from flask import Blueprint
 dtale = Blueprint('dtale', __name__, url_prefix='/dtale')
 
 # flake8: NOQA
-from dtale.app import show, get_instance, instances  # isort:skip
+from dtale.app import show, get_instance, instances, offline_chart  # isort:skip
 from dtale.cli.loaders import LOADERS  # isort:skip
 
 for loader_name, loader in LOADERS.items():
